#!/bin/sh
echo 'name: dataenc
version: 0.14.0.3
id: dataenc-0.14.0.3-de84533a90515987298bdce19a0f1916

license: BSD3
copyright: Magnus Therning, 2007-2011
maintainer: magnus@therning.org
stability:
homepage: http://www.haskell.org/haskellwiki/Library/Data_encoding
package-url:
synopsis: Data encoding library
description: Data encoding library currently providing Base16, Base32,
             Base32Hex, Base64, Base64Url, Base85, Python string escaping,
             Quoted-Printable, URL encoding, uuencode, xxencode, and yEncoding.
category: Codec
author: Magnus Therning
pkgpath: devel/hs-dataenc
exposed: True
exposed-modules: Codec.Binary.Base16 Codec.Binary.Base32
                 Codec.Binary.Base32Hex Codec.Binary.Base64 Codec.Binary.Base64Url
                 Codec.Binary.Base85 Codec.Binary.DataEncoding
                 Codec.Binary.PythonString Codec.Binary.QuotedPrintable
                 Codec.Binary.Url Codec.Binary.Uu Codec.Binary.Xx Codec.Binary.Yenc
hidden-modules: Codec.Binary.Util
trusted: False
import-dirs: /usr/local/lib/ghc/dataenc-0.14.0.3
library-dirs: /usr/local/lib/ghc/dataenc-0.14.0.3
hs-libraries: HSdataenc-0.14.0.3
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: array-0.4.0.0-0b6c5ca7e879a14d110ca4c001dd9297
         base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-dataenc-0.14.0.3/html/dataenc.haddock
haddock-html: /usr/local/share/doc/hs-dataenc-0.14.0.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
